@@ -11,8 +11,9 @@
     Implements high-level support for HDF5 file objects.
 """
 
-import sys
+import inspect
 import os
+import sys
 from warnings import warn
 
 from .compat import filename_decode, filename_encode
@@ -27,16 +28,12 @@ ros3 = h5.get_config().ros3
 direct_vfd = h5.get_config().direct_vfd
 hdf5_version = version.hdf5_version_tuple[0:3]
 
-swmr_support = False
-if hdf5_version >= h5.get_config().swmr_min_hdf5_version:
-    swmr_support = True
+swmr_support = True
 
 
-libver_dict = {'earliest': h5f.LIBVER_EARLIEST, 'latest': h5f.LIBVER_LATEST}
+libver_dict = {'earliest': h5f.LIBVER_EARLIEST, 'latest': h5f.LIBVER_LATEST,
+               'v108': h5f.LIBVER_V18, 'v110': h5f.LIBVER_V110}
 libver_dict_r = dict((y, x) for x, y in libver_dict.items())
-if hdf5_version >= (1, 10, 2):
-    libver_dict.update({'v108': h5f.LIBVER_V18, 'v110': h5f.LIBVER_V110})
-    libver_dict_r.update({h5f.LIBVER_V18: 'v108', h5f.LIBVER_V110: 'v110'})
 
 if hdf5_version >= (1, 11, 4):
     libver_dict.update({'v112': h5f.LIBVER_V112})
@@ -112,10 +109,12 @@ def registered_drivers():
     return frozenset(_drivers)
 
 
-def make_fapl(driver, libver, rdcc_nslots, rdcc_nbytes, rdcc_w0, locking,
-              page_buf_size, min_meta_keep, min_raw_keep,
-              alignment_threshold, alignment_interval, meta_block_size,
-              **kwds):
+def make_fapl(
+    driver, libver=None, rdcc_nslots=None, rdcc_nbytes=None, rdcc_w0=None,
+    locking=None, page_buf_size=None, min_meta_keep=0, min_raw_keep=0,
+    alignment_threshold=1, alignment_interval=1, meta_block_size=None,
+    **kwds
+):
     """ Set up a file access property list """
     plist = h5p.create(h5p.FILE_ACCESS)
 
@@ -174,7 +173,15 @@ def make_fapl(driver, libver, rdcc_nslots, rdcc_nbytes, rdcc_w0, locking,
     except KeyError:
         raise ValueError('Unknown driver type "%s"' % driver)
     else:
-        set_fapl(plist, **kwds)
+        if driver == 'ros3':
+            token = kwds.pop('session_token', None)
+            set_fapl(plist, **kwds)
+            if token:
+                if hdf5_version < (1, 14, 2):
+                    raise ValueError('HDF5 >= 1.14.2 required for AWS session token')
+                plist.set_fapl_ros3_token(token)
+        else:
+            set_fapl(plist, **kwds)
 
     return plist
 
@@ -339,7 +346,7 @@ class File(Group):
         fapl = self.id.get_access_plist()
         return fapl.get_meta_block_size()
 
-    if mpi and hdf5_version >= (1, 8, 9):
+    if mpi:
 
         @property
         @with_phil
@@ -364,13 +371,10 @@ class File(Group):
     @with_phil
     def swmr_mode(self, value):
         # pylint: disable=missing-docstring
-        if swmr_support:
-            if value:
-                self.id.start_swmr_write()
-            else:
-                raise ValueError("It is not possible to forcibly switch SWMR mode off.")
+        if value:
+            self.id.start_swmr_write()
         else:
-            raise RuntimeError('SWMR support is not available in HDF5 version {}.{}.{}.'.format(*hdf5_version))
+            raise ValueError("It is not possible to forcibly switch SWMR mode off.")
 
     def __init__(self, name, mode='r', driver=None, libver=None, userblock_size=None, swmr=False,
                  rdcc_nslots=None, rdcc_nbytes=None, rdcc_w0=None, track_order=None,
@@ -396,8 +400,7 @@ class File(Group):
             recommended), 'core', 'sec2', 'direct', 'stdio', 'mpio', 'ros3'.
         libver
             Library version bounds.  Supported values: 'earliest', 'v108',
-            'v110', 'v112'  and 'latest'. The 'v108', 'v110' and 'v112'
-            options can only be specified with the HDF5 1.10.2 library or later.
+            'v110', 'v112'  and 'latest'.
         userblock_size
             Desired size of user block.  Only allowed when creating a new
             file (mode w, w- or x).
@@ -479,7 +482,7 @@ class File(Group):
 
         alignment_threshold
             Together with ``alignment_interval``, this property ensures that
-            any file object greater than or equal in size to the alignement
+            any file object greater than or equal in size to the alignment
             threshold (in bytes) will be aligned on an address which is a
             multiple of alignment interval.
 
@@ -496,12 +499,6 @@ class File(Group):
         Additional keywords
             Passed on to the selected file driver.
         """
-        if (fs_strategy or page_buf_size) and hdf5_version < (1, 10, 1):
-            raise ValueError("HDF5 version 1.10.1 or greater required for file space strategy or page buffering support.")
-
-        if swmr and not swmr_support:
-            raise ValueError("The SWMR feature is not available in this version of the HDF5 library")
-
         if driver == 'ros3':
             if ros3:
                 from urllib.parse import urlparse
@@ -573,6 +570,53 @@ class File(Group):
 
         super().__init__(fid)
 
+    _in_memory_file_counter = 0
+
+    @classmethod
+    @with_phil
+    def in_memory(cls, file_image=None, **kwargs):
+        """Create an HDF5 file in memory, without an underlying file
+
+        file_image
+            The initial file contents as bytes (or anything that supports the
+            Python buffer interface). HDF5 takes a copy of this data.
+        block_size
+            Chunk size for new memory alloactions (default 64 KiB).
+
+        Other keyword arguments are like File(), although name, mode,
+        driver and locking can't be passed.
+        """
+        for k in ('driver', 'locking', 'backing_store'):
+            if k in kwargs:
+                raise TypeError(
+                    f"File.in_memory() got an unexpected keyword argument {k!r}"
+                )
+        fcpl_kwargs = {}
+        for k in inspect.signature(make_fcpl).parameters:
+            if k in kwargs:
+                fcpl_kwargs[k] = kwargs.pop(k)
+        fcpl = make_fcpl(**fcpl_kwargs)
+
+        fapl = make_fapl(driver="core", backing_store=False, **kwargs)
+        if file_image:
+            if fcpl_kwargs:
+                kw = ', '.join(fcpl_kwargs)
+                raise TypeError(f"{kw} parameters cannot be used with file_image")
+            fapl.set_file_image(file_image)
+
+        # We have to give HDF5 a filename, but it should never use it.
+        # This is a hint both in memory, and in case a bug ever creates a file.
+        # The name also needs to be different from any other open file;
+        # we use a simple counter (protected by the 'phil' lock) for this.
+        name = b"h5py_in_memory_nonfile_%d"  % cls._in_memory_file_counter
+        cls._in_memory_file_counter += 1
+
+        if file_image:
+            fid = h5f.open(name, h5f.ACC_RDWR, fapl=fapl)
+        else:
+            fid = h5f.create(name, h5f.ACC_EXCL, fapl=fapl, fcpl=fcpl)
+        return cls(fid)
+
     def close(self):
         """ Close the file.  All open objects become invalid """
         with phil:
